@@ -12,7 +12,7 @@ class HTTPClient:
     def __init__(self, api_url: str, token: str) -> None:
         self.api_url = api_url
         self.session = aiohttp.ClientSession(headers={"User-Agent": "Sanctum-TC (https://gitlab.com/lightning-bot/sanctum-tc.git)",
-                                                      "Authorization": f"Bearer {token}"})
+                                                      "X-API-Key": token})
 
     async def close(self):
         """Closes the client session"""
@@ -72,6 +72,9 @@ class HTTPClient:
     async def get_timers(self, *, limit: int = 1):
         return await self.request("GET", "/timers", params={"limit": str(limit)})
 
+    async def get_user_reminder(self, user_id: int, reminder_id: int):
+        return await self.request("GET", f"/users/{user_id}/reminders/{reminder_id}")
+
     async def get_user_reminders(self, user_id: int, *, limit: int = 10):
         return await self.request("GET", f"/users/{user_id}/reminders", params={"limit": str(limit)})
 
@@ -107,3 +110,13 @@ class HTTPClient:
 
     async def bulk_upsert_guild_prefixes(self, guild_id: int, prefixes: List[str]):
         return await self.request("PUT", f"/guilds/{guild_id}/prefixes", data=prefixes)
+
+    # AutoMod
+    async def get_guild_automod_config(self, guild_id: int):
+        return await self.request("GET", f"/guilds/{guild_id}/automod")
+
+    async def get_guild_automod_rules(self, guild_id: int):
+        return await self.request("GET", f"/guilds/{guild_id}/automod/rules")
+
+    async def delete_guild_automod_rules(self, guild_id: int, event: str):
+        return await self.request("DELETE", f"/guilds/{guild_id}/automod/rules/{event}")
